// Product Search and Filter Functions
document.addEventListener('DOMContentLoaded', function() {
    // Product search functionality
    const searchInput = document.getElementById('product-search');
    const searchButton = document.getElementById('search-button');
    const productCards = document.querySelectorAll('.product_tab');
    
    if (searchInput && searchButton) {
        // Search button click
        searchButton.addEventListener('click', function() {
            performSearch();
        });
        
        // Enter key in search field
        searchInput.addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
                e.preventDefault();
                performSearch();
            }
        });
        
        function performSearch() {
            const searchTerm = searchInput.value.toLowerCase().trim();
            
            // If search is empty, show all products
            if (!searchTerm) {
                productCards.forEach(card => {
                    card.style.display = 'block';
                });
                return;
            }
            
            // Filter products based on search term
            productCards.forEach(card => {
                const productName = card.querySelector('.product_content h5 a').textContent.toLowerCase();
                const productContent = card.textContent.toLowerCase();
                
                if (productName.includes(searchTerm) || productContent.includes(searchTerm)) {
                    card.style.display = 'block';
                } else {
                    card.style.display = 'none';
                }
            });
        }
    }
    
    // Quantity increment/decrement on product detail page
    const decreaseBtn = document.getElementById('decrease-quantity');
    const increaseBtn = document.getElementById('increase-quantity');
    const quantityInput = document.getElementById('quantity');
    
    if (decreaseBtn && increaseBtn && quantityInput) {
        decreaseBtn.addEventListener('click', function() {
            let value = parseInt(quantityInput.value);
            if (value > 1) {
                quantityInput.value = value - 1;
            }
        });
        
        increaseBtn.addEventListener('click', function() {
            let value = parseInt(quantityInput.value);
            let max = parseInt(quantityInput.getAttribute('max'));
            if (value < max) {
                quantityInput.value = value + 1;
            }
        });
    }
    
    // Enhanced filter application
    const applyFilterBtn = document.querySelector('.apply_filter');
    if (applyFilterBtn) {
        applyFilterBtn.addEventListener('click', function() {
            const categoryInputs = document.querySelectorAll('input[name="categories[]"]:checked');
            const sizeSelect = document.getElementById('size');
            
            // Build query string with selected filters
            let queryParams = new URLSearchParams();
            
            categoryInputs.forEach(input => {
                queryParams.append('categories[]', input.value);
            });
            
            if (sizeSelect && sizeSelect.value) {
                queryParams.append('size', sizeSelect.value);
            }
            
            // Redirect to filtered results
            window.location.href = `${window.location.pathname}?${queryParams.toString()}`;
        });
    }
});
