<!doctype html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Ampcontrol Uniform Portal - Login</title>
    <link rel="stylesheet" href="{{ asset('css/style.css') }}">
    <link rel="stylesheet" href="{{ asset('css/stylesheet.css') }}">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.5/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-SgOJa3DmI69IUzQ2PVdRZhwQ+dy64/BUtbMJw1MZ8t5HZApcHrRKUc4W0kG879m7" crossorigin="anonymous">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <style>
        body {
            background-color: #f8f9fa;
            font-family: 'Arial', sans-serif;
        }
        .login-page {
            min-height: 100vh;
            display: flex;
            align-items: center;
            position: relative;
            overflow: hidden;
        }
        .login-card {
            background: white;
            border-radius: 15px;
            box-shadow: 0 8px 30px rgba(0,0,0,0.05);
            padding: 40px;
            margin: 30px 0;
            position: relative;
            z-index: 2;
        }
        .login-card h3 {
            font-weight: 700;
            margin-bottom: 10px;
            color: #333;
        }
        .login-card p {
            color: #6c757d;
            margin-bottom: 30px;
        }
        .form-control {
            padding: 12px 15px;
            border-radius: 8px;
            border: 1px solid #ced4da;
            transition: all 0.2s ease;
            background-color: #f8f9fa;
        }
        .form-control:focus {
            border-color: #ff8800;
            box-shadow: 0 0 0 0.25rem rgba(255, 136, 0, 0.15);
        }
        .form-label {
            font-weight: 600;
            font-size: 14px;
            color: #444;
        }
        .btn-primary {
            background: #ff8800;
            border: none;
            padding: 12px;
            border-radius: 8px;
            font-weight: 600;
            transition: all 0.3s ease;
        }
        .btn-primary:hover {
            background: #e67a00;
            transform: translateY(-2px);
            box-shadow: 0 4px 12px rgba(255, 136, 0, 0.2);
        }
        .globle_image {
            position: absolute;
            right: 0;
            top: 0;
            height: 100%;
            width: 40%;
            background-color: #2c2c2c;
            display: flex;
            align-items: center;
            justify-content: center;
        }
        .input-group-text {
            background-color: transparent;
            border-left: none;
            cursor: pointer;
        }
        .password-toggle {
            border-left: none;
            background-color: #f8f9fa;
        }
        
        @media (max-width: 991px) {
            .globle_image {
                display: none;
            }
            .login-card {
                margin: 20px;
                padding: 30px;
            }
        }
    </style>
</head>
<body>

@if(session('error'))
    <div class="alert alert-danger alert-dismissible fade show position-absolute top-0 start-50 translate-middle-x mt-4" role="alert" style="z-index: 1000">
        {{ session('error') }}
        <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
    </div>
@endif

<div class="login-page">
    <div class="container">
        <div class="row justify-content-start">
            <div class="col-lg-6 col-md-8 col-sm-12">
                <div class="login-card">
                    <img src="/interior.images.local/logo.png" alt="Logo" style="max-width: 180px; margin-bottom: 30px;">
                    <h3>Welcome to Ampcontrol Uniform Portal</h3>
                    <p>Enter your credentials to access your account</p>
                    
                    <form method="post" action="{{$url}}" enctype="multipart/form-data">
                        @csrf

                        <div class="mb-4">
                            <label for="name" class="form-label">Username</label>
                            <div class="input-group">
                                <span class="input-group-text bg-light"><i class="fas fa-user text-muted"></i></span>
                                <input id="name" type="text" class="form-control @error('name') is-invalid @enderror"
                                    name="name" value="{{ old('name', $login->name) }}" placeholder="Enter your username">
                            </div>
                            @error('name')
                            <div class="invalid-feedback d-block mt-1">
                                {{ $message }}
                            </div>
                            @enderror
                        </div>

                        <div class="mb-4">
                            <label for="password" class="form-label">Password</label>
                            <div class="input-group">
                                <span class="input-group-text bg-light"><i class="fas fa-lock text-muted"></i></span>
                                <input id="password" type="password" class="form-control @error('password') is-invalid @enderror"
                                    name="password" value="{{ old('password', $login->password) }}" placeholder="Enter your password">
                                <span class="input-group-text password-toggle" onclick="togglePassword()">
                                    <i class="fas fa-eye-slash text-muted" id="toggleIcon"></i>
                                </span>
                            </div>
                            @error('password')
                            <div class="invalid-feedback d-block mt-1">
                                {{ $message }}
                            </div>
                            @enderror
                        </div>

                        <input type="hidden" name="role" value="user">

                        {{-- Submit --}}
                        <div class="d-grid mt-4">
                            <button class="btn btn-primary" type="submit">Sign In</button>
                        </div>
                        
                        <div class="text-center mt-4">
                            <p class="mb-0 text-muted">First time login? Use the temporary password sent to your email</p>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
    <div class="globle_image">
        <img src="/interior.images.local/logo.png" alt="Logo" style="max-width: 80%; height: auto;">
    </div>
</div>

<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="{{ asset('js/jquery.js') }}"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js" integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz" crossorigin="anonymous"></script>
<script>
    function togglePassword() {
        const passwordInput = document.getElementById('password');
        const toggleIcon = document.getElementById('toggleIcon');
        
        if (passwordInput.type === 'password') {
            passwordInput.type = 'text';
            toggleIcon.classList.remove('fa-eye-slash');
            toggleIcon.classList.add('fa-eye');
        } else {
            passwordInput.type = 'password';
            toggleIcon.classList.remove('fa-eye');
            toggleIcon.classList.add('fa-eye-slash');
        }
    }
    
    // Auto-dismiss alerts after 5 seconds
    setTimeout(function() {
        $('.alert').alert('close');
    }, 5000);
</script>
</body>
</html>
